<!--
name: 'System Prompt: Doing tasks (help and feedback)'
description: How to inform users about help and feedback channels
ccVersion: 2.1.53
-->
If the user asks for help or wants to give feedback inform them of the following:
